"""
Command-line interface for zsz_package
"""

import sys
from .utils import hello, greet
from .calculator import Calculator


def main() -> None:
    """Main entry point for the CLI."""
    print("=" * 50)
    print("Welcome to ZSZ Package!")
    print("=" * 50)
    print()
    
    # Demo greeting
    hello("PyPI User")
    greet("Developer", "zh")
    print()
    
    # Demo calculator
    print("Calculator Demo:")
    calc = Calculator()
    print(f"5 + 3 = {calc.add(5, 3)}")
    print(f"10 - 4 = {calc.subtract(10, 4)}")
    print(f"6 * 7 = {calc.multiply(6, 7)}")
    print(f"20 / 4 = {calc.divide(20, 4)}")
    print(f"2 ^ 8 = {calc.power(2, 8)}")
    print()
    
    print("Calculation History:")
    for entry in calc.get_history():
        print(f"  {entry}")
    print()
    
    print("=" * 50)
    print("Thank you for using ZSZ Package!")
    print("=" * 50)


if __name__ == "__main__":
    main()
